@@ -5,13 +5,13 @@ from os.path import getsize
 from bitfield import BitField
 from django.db import transaction
 from django.db.models import DateTimeField, TextField, PositiveIntegerField
+
 from isc_common import delAttr, replace_alt_set, setAttr
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
 from isc_common.management.commands.refresh_mat_views import refresh_mat_view
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.audit import AuditModel
-
 from kaf_pas.ckk.models.attr_type import Attr_type
 from kaf_pas.kd.models.pathes import Pathes
 
@@ -172,7 +172,6 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
     @staticmethod
     def delete(id, user):
         from isc_common.auth.models.user import User
-        from kaf_pas.ckk.models.item import Item
         from kaf_pas.kd.models.document_attr_cross import Document_attr_cross
         from kaf_pas.kd.models.documents_thumb import Documents_thumb
         from kaf_pas.kd.models.documents_thumb10 import Documents_thumb10
@@ -185,15 +184,15 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
             raise Exception(f'user  must be a User instance.')
 
         res = 0
+        lotsman_res = 0
 
         Uploades_documents.objects.filter(document_id=id).delete()
         Documents_thumb.objects.filter(document_id=id).delete()
         Documents_thumb10.objects.filter(document_id=id).delete()
         Document_attr_cross.objects.filter(document_id=id).delete()
 
-        for item in Item.objects.filter(document_id=id):
-            from kaf_pas.ckk.models.item import ItemManager
-            ItemManager.delete_recursive(item_id=item.id, user=user)
+        # for item in Item.objects.filter(document_id=id):
+        #     ItemManager.delete_recursive(item_id=item.id, user=user)
 
         Lotsman_documents_hierarcy_files.objects.filter(lotsman_document__document_id=id).delete()
 
@@ -204,9 +203,10 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
             Lotsman_documents_hierarcy_refs.objects.filter(child=lotsman_documents_hierarcy).delete()
             Lotsman_documents_hierarcy_refs.objects.filter(parent=lotsman_documents_hierarcy).delete()
             lotsman_documents_hierarcy.delete()
+            lotsman_res += 1
 
         res += Documents.objects.filter(id=id).delete()[0]
-        return res
+        return res, lotsman_res
 
     def deleteFromRequest(self, request):
         from kaf_pas.ckk.models.item import Item
@@ -314,7 +314,7 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
 
         top_level = Contants.objects.get(code='audo_top_level')
 
-        #К4.5350-001(307-1Э).78.15.000
+        # К4.5350-001(307-1Э).78.15.000
         with transaction.atomic():
             if document.file_document.lower().find('мусор') == -1:
 
@@ -337,7 +337,7 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
                         # if logger:
                         #     logger.logging(f'\nAdded: {item_refs} as tpo level', 'debug')
                     else:
-                        raise    
+                        raise
 
                     if STMP_2 != None:
                         DocumentManager.rec_image_cwd(parent.id, STMP_2.value_str, logger)
