@@ -172,9 +172,10 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                     delAttr(v, 'operation__full_name')
                     for k1, v1 in v.items():
                         if k1.find('_') == -1:
-                            data1.setdefault(k1, v1)
+                            setAttr(data1, k1, v1)
                     data1.setdefault('_operation', 'update')
                     res = super().filter(id=v.get('id')).update(**data1)
+                    break
                 else:
                     delAttr(_data, 'operation__full_name')
                     res = super().filter(id=data.get('id')).update(**_data)
